@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Any, Dict, Iterable, Type, Union
+from typing import Any, Dict, Iterable, Literal, Type, Union
 
 import yaml
 from grai_client.schemas.edge import Edge
@@ -15,7 +15,9 @@ class Schema(GraiBaseModel):
     entity: GraiType
 
     @classmethod
-    def to_model(cls, item: Dict, version: str, typing_type: str) -> GraiType:
+    def to_model(
+        cls, item: Dict, version: Literal["v1"], typing_type: Literal["Node", "Edge"]
+    ) -> GraiType:
         result = {
             "type": typing_type,
             "version": version,
